README
######

.. image:: https://travis-ci.org/mlenzen/lenzm_utils.svg?branch=master
	:target: https://travis-ci.org/mlenzen/lenzm_utils
	:alt: Build Status


.. image:: https://coveralls.io/repos/mlenzen/lenzm_utils/badge.svg?branch=master
	:target: https://coveralls.io/r/mlenzen/lenzm_utils?branch=master
	:alt: Coverage


Overview
========

This package includes one module - ``lenzm_utils``.


Getting Started
===============

.. code:: python

	 >>> import lenzm_utils

Installation
============

``pip install git+https://github.com/mlenzen/lenzm_utils.git#egg=lenzm_utils``

Usage
=====
	``import lenzm_utils``

Features
========

:Author: Michael Lenzen
:Copyright: 2018 Michael Lenzen
:License: MIT
:GitHub: https://github.com/mlenzen/lenzm_utils
